==> ooo_dev_tools-0.47.11-py3-none-any.whl: ooodev/dialog/__init__.py <==
# pylint: disable=wrong-import-order
# region dialogs
from ooo.dyn.awt.push_button_type import PushButtonType as PushButtonType
from ooo.dyn.awt.pos_size import PosSizeEnum as PosSizeEnum
from ooo.dyn.style.vertical_alignment import VerticalAlignment as VerticalAlignment
from ooo.dyn.awt.image_scale_mode import ImageScaleModeEnum as ImageScaleModeEnum
from ooo.dyn.awt.line_end_format import LineEndFormatEnum as LineEndFormatEnum
from ooodev.utils.kind.align_kind import AlignKind as AlignKind
from ooodev.utils.kind.border_kind import BorderKind as BorderKind
from ooodev.utils.kind.date_format_kind import DateFormatKind as DateFormatKind
from ooodev.utils.kind.horz_ver_kind import HorzVertKind as HorzVertKind
from ooodev.utils.kind.orientation_kind import OrientationKind as OrientationKind
from ooodev.utils.kind.state_kind import StateKind as StateKind
from ooodev.utils.kind.time_format_kind import TimeFormatKind as TimeFormatKind
from ooodev.utils.kind.tri_state_kind import TriStateKind as TriStateKind
from ooodev.dialog.dialogs import Dialogs as Dialogs
from ooodev.dialog.dialog import Dialog as Dialog

# endregion dialogs

# region input
from ooodev.dialog.input import Input as Input

# endregion input

# region msgbox
from ooo.dyn.awt.message_box_results import MessageBoxResultsEnum as MessageBoxResultsEnum
from ooo.dyn.awt.message_box_buttons import MessageBoxButtonsEnum as MessageBoxButtonsEnum
from ooo.dyn.awt.message_box_type import MessageBoxType as MessageBoxType
from ooodev.dialog.msgbox import MsgBox as MsgBox

# endregion msgbox

__all__ = ["Dialogs", "Dialog"]

==> ooo_dev_tools-0.53.0-py3-none-any.whl: ooodev/dialog/__init__.py <==
# pylint: disable=wrong-import-order

# region dialogs
from ooo.dyn.awt.push_button_type import PushButtonType as PushButtonType
from ooo.dyn.awt.pos_size import PosSizeEnum as PosSizeEnum
from ooo.dyn.style.vertical_alignment import VerticalAlignment as VerticalAlignment
from ooo.dyn.awt.image_scale_mode import ImageScaleModeEnum as ImageScaleModeEnum
from ooo.dyn.awt.line_end_format import LineEndFormatEnum as LineEndFormatEnum
from ooodev.utils.kind.align_kind import AlignKind as AlignKind
from ooodev.utils.kind.border_kind import BorderKind as BorderKind
from ooodev.utils.kind.date_format_kind import DateFormatKind as DateFormatKind
from ooodev.utils.kind.horz_ver_kind import HorzVertKind as HorzVertKind
from ooodev.utils.kind.orientation_kind import OrientationKind as OrientationKind
from ooodev.utils.kind.state_kind import StateKind as StateKind
from ooodev.utils.kind.time_format_kind import TimeFormatKind as TimeFormatKind
from ooodev.utils.kind.tri_state_kind import TriStateKind as TriStateKind
from ooodev.dialog.dialogs import Dialogs as Dialogs
from ooodev.dialog.dialog import Dialog as Dialog

# endregion dialogs

# region input
from ooodev.dialog.input import Input as Input

# endregion input

# region msgbox
from ooo.dyn.awt.message_box_results import (
    MessageBoxResultsEnum as MessageBoxResultsEnum,
)
from ooo.dyn.awt.message_box_buttons import (
    MessageBoxButtonsEnum as MessageBoxButtonsEnum,
)
from ooo.dyn.awt.message_box_type import MessageBoxType as MessageBoxType
from ooodev.dialog.msgbox import MsgBox as MsgBox

# endregion msgbox

__all__ = ["Dialogs", "Dialog"]

import uno  # noqa # type: ignore
